@@ -73,6 +73,11 @@
         <source>ERROR: Nothing selected to paste</source>
         <translation>خطأ : لا شيء مختارة للصق</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Cannot create symlink in this folder</source>
+        <translation>لا يمكن انشاء ارتباط بهذا المجلد</translation>
+    </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
@@ -119,6 +124,11 @@
         <source>Extract destination</source>
         <translation>مسار فك الضغط</translation>
     </message>
+    <message>
+        <location filename="../home.cpp" line="10"/>
+        <source>Symlink destination</source>
+        <translation>مسار الإرتباط</translation>
+    </message>
 </context>
 <context>
     <name>Clipboard</name>
@@ -173,6 +183,11 @@
         <source>Open terminal here</source>
         <translation>فتح الترمنل هنا</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Create new symlink</source>
+        <translation>انشاء ارتباط جديد</translation>
+    </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
@@ -302,7 +317,7 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Copying...</source>
-        <translation>...جاري النسخ </translation>
+        <translation>جاري النسخ ...</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
