@@ -73,6 +73,11 @@
         <source>ERROR: Nothing selected to paste</source>
         <translation>FEHLER: Nichts zum Einfügen markiert</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Cannot create symlink in this folder</source>
+        <translation>Verknüpfung kann in diesem Ordner nicht erstellt werden</translation>
+    </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
@@ -119,6 +124,11 @@
         <source>Extract destination</source>
         <translation>Ziel für die Dekomprimierung</translation>
     </message>
+    <message>
+        <location filename="../home.cpp" line="10"/>
+        <source>Symlink destination</source>
+        <translation>Ziel der Verknüpfung</translation>
+    </message>
 </context>
 <context>
     <name>Clipboard</name>
@@ -173,6 +183,11 @@
         <source>Open terminal here</source>
         <translation>Terminal hier öffnen</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Create new symlink</source>
+        <translation>Neue Verknüpfung erstellen</translation>
+    </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
